R.m.theta: Calculates the R value given model and parameters
Description
Provides a function to calculate F_m(theta_m).
Usage
R.m.theta(S, m, theta, A, weight = FALSE, nBB = 100)
Value
a numeric value or a numeric verctor when weight = TRUE. the value of R or the values of R using Bayesian bootstap replicates of the surrogate marker.
Arguments
- S
-
- m
-
- theta
-
- A
-
- weight
-
- nBB
-